bgen_file
---------

.. currentmodule:: cbgen

.. autosummary::

    bgen_file
    bgen_file.close
    bgen_file.contain_samples
    bgen_file.create_metafile
    bgen_file.filepath
    bgen_file.nsamples
    bgen_file.nvariants
    bgen_file.read_genotype
    bgen_file.read_probability
    bgen_file.read_samples

.. autoclass:: bgen_file
   :members:
   :inherited-members:
